pub trait Incoming {
type Expected;
}Expand description
Indicate that a protocol will receive a message, and specify what type it is, so we can decide in an offer which arm we got a message for.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".